==> kubernetes-model-apiextensions-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceColumnDefinitionFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
public class CustomResourceColumnDefinitionFluentImpl<A extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinitionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinitionFluent<A>{
  public CustomResourceColumnDefinitionFluentImpl() {
  }
  public CustomResourceColumnDefinitionFluentImpl(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition instance) {
    this.withJSONPath(instance.getJSONPath()); 
    this.withDescription(instance.getDescription()); 
    this.withFormat(instance.getFormat()); 
    this.withName(instance.getName()); 
    this.withPriority(instance.getPriority()); 
    this.withType(instance.getType()); 
  }
  private java.lang.String jSONPath;
  private java.lang.String description;
  private java.lang.String format;
  private java.lang.String name;
  private java.lang.Integer priority;
  private java.lang.String type;
  public java.lang.String getJSONPath() {
    return this.jSONPath;
  }
  public A withJSONPath(java.lang.String jSONPath) {
    this.jSONPath=jSONPath; return (A) this;
  }
  public java.lang.Boolean hasJSONPath() {
    return this.jSONPath != null;
  }
  
  /**
   * Method is deprecated. use withJSONPath instead.
   */
  @java.lang.Deprecated
  public A withNewJSONPath(java.lang.String arg0) {
    return (A)withJSONPath(new String(arg0));
  }
  public java.lang.String getDescription() {
    return this.description;
  }
  public A withDescription(java.lang.String description) {
    this.description=description; return (A) this;
  }
  public java.lang.Boolean hasDescription() {
    return this.description != null;
  }
  
  /**
   * Method is deprecated. use withDescription instead.
   */
  @java.lang.Deprecated
  public A withNewDescription(java.lang.String arg0) {
    return (A)withDescription(new String(arg0));
  }
  public java.lang.String getFormat() {
    return this.format;
  }
  public A withFormat(java.lang.String format) {
    this.format=format; return (A) this;
  }
  public java.lang.Boolean hasFormat() {
    return this.format != null;
  }
  
  /**
   * Method is deprecated. use withFormat instead.
   */
  @java.lang.Deprecated
  public A withNewFormat(java.lang.String arg0) {
    return (A)withFormat(new String(arg0));
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public java.lang.Integer getPriority() {
    return this.priority;
  }
  public A withPriority(java.lang.Integer priority) {
    this.priority=priority; return (A) this;
  }
  public java.lang.Boolean hasPriority() {
    return this.priority != null;
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CustomResourceColumnDefinitionFluentImpl that = (CustomResourceColumnDefinitionFluentImpl) o;
    if (jSONPath != null ? !jSONPath.equals(that.jSONPath) :that.jSONPath != null) return false;
    if (description != null ? !description.equals(that.description) :that.description != null) return false;
    if (format != null ? !format.equals(that.format) :that.format != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (priority != null ? !priority.equals(that.priority) :that.priority != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(jSONPath,  description,  format,  name,  priority,  type,  super.hashCode());
  }
  
}

==> kubernetes-model-apiextensions-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceColumnDefinitionFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class CustomResourceColumnDefinitionFluentImpl<A extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinitionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinitionFluent<A>{
  public CustomResourceColumnDefinitionFluentImpl() {
  }
  public CustomResourceColumnDefinitionFluentImpl(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition instance) {
    this.withJSONPath(instance.getJSONPath()); 
    this.withDescription(instance.getDescription()); 
    this.withFormat(instance.getFormat()); 
    this.withName(instance.getName()); 
    this.withPriority(instance.getPriority()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String jSONPath;
  private java.lang.String description;
  private java.lang.String format;
  private java.lang.String name;
  private java.lang.Integer priority;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getJSONPath() {
    return this.jSONPath;
  }
  public A withJSONPath(java.lang.String jSONPath) {
    this.jSONPath=jSONPath; return (A) this;
  }
  public java.lang.Boolean hasJSONPath() {
    return this.jSONPath != null;
  }
  
  /**
   * Method is deprecated. use withJSONPath instead.
   */
  @java.lang.Deprecated
  public A withNewJSONPath(java.lang.String arg0) {
    return (A)withJSONPath(new String(arg0));
  }
  public java.lang.String getDescription() {
    return this.description;
  }
  public A withDescription(java.lang.String description) {
    this.description=description; return (A) this;
  }
  public java.lang.Boolean hasDescription() {
    return this.description != null;
  }
  
  /**
   * Method is deprecated. use withDescription instead.
   */
  @java.lang.Deprecated
  public A withNewDescription(java.lang.String arg0) {
    return (A)withDescription(new String(arg0));
  }
  public java.lang.String getFormat() {
    return this.format;
  }
  public A withFormat(java.lang.String format) {
    this.format=format; return (A) this;
  }
  public java.lang.Boolean hasFormat() {
    return this.format != null;
  }
  
  /**
   * Method is deprecated. use withFormat instead.
   */
  @java.lang.Deprecated
  public A withNewFormat(java.lang.String arg0) {
    return (A)withFormat(new String(arg0));
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public java.lang.Integer getPriority() {
    return this.priority;
  }
  public A withPriority(java.lang.Integer priority) {
    this.priority=priority; return (A) this;
  }
  public java.lang.Boolean hasPriority() {
    return this.priority != null;
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CustomResourceColumnDefinitionFluentImpl that = (CustomResourceColumnDefinitionFluentImpl) o;
    if (jSONPath != null ? !jSONPath.equals(that.jSONPath) :that.jSONPath != null) return false;
    if (description != null ? !description.equals(that.description) :that.description != null) return false;
    if (format != null ? !format.equals(that.format) :that.format != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (priority != null ? !priority.equals(that.priority) :that.priority != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(jSONPath,  description,  format,  name,  priority,  type,  additionalProperties,  super.hashCode());
  }
  
}
